declare module BA.Ui.Widgets {
    class Widget {
        private _WidgetLoadState;
        private _DefaultFocusOnNextLoaded;
        private _TriggerOnContentLoadedAfterNextLoad;
        protected IconDefaultUrlSuffix: string;
        Id: BA.Classes.Guid;
        ParentWidgetId: BA.Classes.Guid;
        PageId: BA.Classes.Guid;
        PageConfigId: BA.Classes.Guid;
        DelayedLoad: boolean;
        ProvidedParameterTypes: string;
        IsAutoCollapsed: boolean;
        IsCollapsed: boolean;
        WidgetType: string;
        RefreshOnExpand: boolean;
        protected Collapsible: boolean;
        constructor(widgetId: BA.Classes.Guid, parentWidgetId: BA.Classes.Guid, pageConfigId: BA.Classes.Guid, widgetType: string, delayedLoad?: boolean);
        get ParameterInfo(): any;
        get WidgetLoadState(): WidgetState;
        protected SetWidgetState(value: WidgetState, blockWidgetIfNotLoaded?: boolean, stateMessage?: string, forceCollapseAction?: boolean): void;
        protected ShowErrorMessage(errorText?: string): void;
        protected ShowContentErrorMessage(errorText?: string): void;
        protected RemoveWidgetStateAndTexts(): void;
        protected BlockWidgetUI(blockedText?: string): void;
        protected UnblockWidgetUI(): void;
        protected BlockWidgetContentUI(blockedText?: string): void;
        protected UnblockWidgetContentUI(): void;
        protected AddActions(): void;
        protected AddRefreshAction(): void;
        /**
         * Action for collapsing a widget
         * */
        protected AddCollapseAction(): void;
        /**
         * Action for maximizing a widget
         * */
        protected AddMaximizeAction(): void;
        protected TriggerWidgetSourceParameterChanged(): void;
        protected AttachToParameterSourceEvents(): void;
        Init(): void;
        OnContentLoaded(): void;
        GetWidgetJQ(): JQuery;
        GetWidgetJQIdSelector(): string;
        ReadSourceParameterJsonString(): string;
        GetProvidedParameterJsonString(parameterType: string): string;
        private GetProvidedParameter;
        protected SetProvidedParameter<T extends Parameters.WidgetParameterBase>(parameterType: string, value: T): void;
        Refresh(blockWidget?: boolean): void;
        /**
         * Action method: maximize and restore a widget
         * */
        RestoreSize(): void;
        /**
         * Action method: objectcollapse and expand a widget
         * @param setUISetting set user spefic ui setting for collapsed status, default = true
         */
        Collapse(setUISetting?: boolean): void;
        /**
         * Method to be called before Widget is Expanding
         * */
        protected BeforeExpanding(): boolean;
        /**
         * Method to be called before Widget is Collapsing.
         * */
        protected BeforeCollapsing(): boolean;
        /**
         * Method to be called when widget is collapsed.
         */
        protected OnCollapsed(): void;
        /**
         * Method to be called when widget size is Restored.
         */
        protected OnSizeRestored(): void;
        /**
         * Method to be called when widget is Maximized.
         */
        protected OnMaximized(): void;
        /**
         * Method to be called when widget is expanded.
         */
        protected OnExpanded(): void;
        protected OnParameterChanged(blockWidget?: boolean): void;
        protected LoadWidgetContent(blockWidget?: boolean, async?: boolean): void;
        AddWidgetAction(iconName: string, actionName: string, tooltip: string, sortOrder: number, onClick: Function): void;
        /**
         * Find out if a certain action is configured for the current widget
         * @param actionName name of the widget action to check for
         */
        GetWidgetActionIsAvailable(actionName: string): boolean;
        DefaultFocusInternal(callback?: Function): void;
        DefaultFocus(callback?: Function): void;
        private HandleLostHover;
        /**
         * Get a user specific UI setting
         * @param option the name of the setting as string
         * @param scope enum value of scope
         * @param onDone function to be called when done for custom handling
         * @param onError function to be called if an error occurs for custom error handling
         */
        protected GetUISetting(option: string, scope: WidgetUIScopes, onDone?: (response: any) => void, onError?: (response: any) => void): any;
        /**
         * Set a user specific UI setting
         * @param option the name of the setting as string
         * @param scope enum value of scope
         * @param onDone function to be called when done for custom handling
         * @param onError function to be called if an error occurs for custom error handling
         */
        protected SetUISetting(option: string, scope: WidgetUIScopes, value: any, onDone?: (response: any) => void, onError?: (response: any) => void): void;
        /**
         * Get the scope value for a user setting.
         * @param scope enum value of scope
         */
        private GetScopeValue;
    }
}
declare enum WidgetState {
    NotLoaded = "1",
    Loading = "2",
    Loaded = "3",
    Blocked = "4",
    Error = "5",
    ContentBlocked = "6",
    ContentError = "7"
}
declare enum WidgetParameterSource {
    None = "554D0BB4-457A-46B2-B457-C2326D365977",
    Page = "F5BC0E94-2819-4700-8567-14AC62DE920F",
    OtherWidget = "44943B91-AE30-4948-A1CA-0AEFF31E7015"
}
declare enum WidgetUIScopes {
    Widget = 0,
    Page = 1,
    Type = 2
}
